summaryrefslogtreecommitdiffstats
path: root/libcutils/dlmalloc_stubs.c
diff options
context:
space:
mode:
authorIan Rogers <irogers@google.com>2012-08-28 15:52:20 -0700
committerIan Rogers <irogers@google.com>2012-08-28 15:52:20 -0700
commitfd7f1b6a50388bb3e21a744af89b184b8f911e9c (patch)
treeb5616a21a2aaf6a049f970e3dbcec74586c0920d /libcutils/dlmalloc_stubs.c
parent59c778e9885f1a1a483bdc1b2287fc2d816c883c (diff)
downloadsystem_core-fd7f1b6a50388bb3e21a744af89b184b8f911e9c.zip
system_core-fd7f1b6a50388bb3e21a744af89b184b8f911e9c.tar.gz
system_core-fd7f1b6a50388bb3e21a744af89b184b8f911e9c.tar.bz2
Revert "Revert "Upgrade to dlmalloc 2.8.5.""
This reverts commit 42b83c6df7e4f65461a32a711d5dd4f46b9b85e0.
Diffstat (limited to 'libcutils/dlmalloc_stubs.c')
-rw-r--r--libcutils/dlmalloc_stubs.c20
1 files changed, 13 insertions, 7 deletions
diff --git a/libcutils/dlmalloc_stubs.c b/libcutils/dlmalloc_stubs.c
index 1ced147..c327a55 100644
--- a/libcutils/dlmalloc_stubs.c
+++ b/libcutils/dlmalloc_stubs.c
@@ -14,16 +14,22 @@
* limitations under the License.
*/
-/* No-op stubs for functions defined in system/bionic/bionic/dlmalloc.c.
- */
-void dlmalloc_walk_free_pages()
-{
-}
+#include "../../../bionic/libc/bionic/dlmalloc.h"
+#include "cutils/log.h"
-void dlmalloc_walk_heap()
+/*
+ * Stubs for functions defined in bionic/libc/bionic/dlmalloc.c. These
+ * are used in host builds, as the host libc will not contain these
+ * functions.
+ */
+void dlmalloc_inspect_all(void(*handler)(void*, void *, size_t, void*),
+ void* arg)
{
+ ALOGW("Called host unimplemented stub: dlmalloc_inspect_all");
}
-void dlmalloc_trim()
+int dlmalloc_trim(size_t unused)
{
+ ALOGW("Called host unimplemented stub: dlmalloc_trim");
+ return 0;
}